==> hylafax_4.3.1.orig.tar.gz: hylafax-4.3.1/faxd/Class0.h <==
/*	$Id: Class0.h,v 1.3 2006/03/17 16:47:07 lhoward Exp $ */
/*
 * Copyright (c) 1994-1996 Sam Leffler
 * Copyright (c) 1994-1996 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _Class0Modem_
#define	_Class0Modem_
/*
 * Class 0 (data) Modem Driver Interface.
 */
#include "ClassModem.h"

class Class0Modem : public ClassModem {
public:
    Class0Modem(ModemServer&, const ModemConfig&);
    ~Class0Modem();

    bool setupModem(bool isSend = true);
    virtual bool setupFlowControl(FlowControl fc);
    CallStatus	dial(const char* number, fxStr& emsg);
    CallStatus dialResponse(fxStr& emsg);

    bool isFaxModem() const;			// XXX safe to cast
};
#endif /* _Class0Modem_ */

==> hylafax_4.4.3.orig.tar.gz: hylafax-4.4.3/faxd/Class0.h <==
/*	$Id: Class0.h,v 1.4 2007/06/04 17:11:07 aidan Exp $ */
/*
 * Copyright (c) 1994-1996 Sam Leffler
 * Copyright (c) 1994-1996 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _Class0Modem_
#define	_Class0Modem_
/*
 * Class 0 (data) Modem Driver Interface.
 */
#include "ClassModem.h"

class Class0Modem : public ClassModem {
public:
    Class0Modem(ModemServer&, const ModemConfig&);
    ~Class0Modem();

    bool setupModem(bool isSend = true);
    virtual bool setupFlowControl(FlowControl fc);
    CallStatus	dial(const char* number, Status& eresult);
    CallStatus dialResponse(Status& eresult);

    bool isFaxModem() const;			// XXX safe to cast
};
#endif /* _Class0Modem_ */
